# A Notebook widget for Tcl/Tk
# $Revision: 1.3 $ $Date: 2003/11/22 00:00:35 $
#
# This version have been modified by Brian Toby to 
#        define Notebook:resize
#        deactivate tabs for notebook pages that have "-state disabled"
#        define a -command configuration option 
#
# Copyright (C) 1996,1997,1998 D. Richard Hipp
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA  02111-1307, USA.
#
# Author contact information:
#   drh@acm.org
#   http://www.hwaci.com/drh/


#
# Create a new notebook widget
#
proc Notebook:create {w args} {
  global Notebook
  set Notebook($w,width) 400
  set Notebook($w,height) 300
  set Notebook($w,pages) {}
  set Notebook($w,top) 0
  set Notebook($w,pad) 5
  set Notebook($w,fg,on) black
  set Notebook($w,fg,off) grey50
  #canvas $w -bd 0 -highlightthickness 0 -takefocus 0
    ttk::notebook $w
#  set Notebook($w,bg) [$w cget -bd]
#  bind $w <1> "Notebook:click $w %x %y"
#  bind $w <Configure> "Notebook:scheduleExpand $w"
  bind $w   <<NotebookTabChanged>> "Notebook:click $w %i %W %R %S"
  eval Notebook:config $w $args
  set cnt 0
  # initalize commands and state for each page
  foreach p $Notebook($w,pages) {
      set Notebook($w,t$cnt,state) 1
      set Notebook($w,c$cnt,command) {}
      if {![winfo exists ${w}.f$cnt]} {
#	  frame ${w}.f$cnt -bd 0
	  $w add [frame ${w}.f$cnt -bd 0] -text $p
      }
      incr cnt
  }
}

#
# Change configuration options for the notebook widget
#
proc Notebook:config {w args} {
  global Notebook
  foreach {tag value} $args {
    switch -- $tag {
      -width {
        set Notebook($w,width) $value
      }
      -height {
        set Notebook($w,height) $value
      }
      -pages {
        set Notebook($w,pages) $value
	  # reinitalize commands and state for each page
	  set cnt 0
	  foreach p $Notebook($w,pages) {
	      set Notebook($w,t$cnt,state) 1
	      set Notebook($w,c$cnt,command) {}
	      incr cnt
	  }
      }
      -padding {
        set Notebook($w,pad) $value
      }
      -bg {
        set Notebook($w,bg) $value
      }
      -fg {
        set Notebook($w,fg,on) $value
      }
      -disabledforeground {
        set Notebook($w,fg,off) $value
      }
    }
  }
}

#
# This routine is called whenever the mouse-button is pressed over
# the notebook.  It determines if any page should be raised and raises
# that page.
#
proc Notebook:click {w l W R S} {
    global Notebook
    set n [$w index current]
    if {$Notebook($w,c$n,command) != {}} {
      if [catch {eval uplevel #0 {$Notebook($w,c$n,command)} } errmsg] {
          error "Notebook command error: $errmsg"
      }
  }


}

#
# For internal use only.  This procedure raised the n-th page of
# the notebook
#
proc Notebook:raise.page {w n} {

}

#
# Change the page-specific configuration options for the notebook
#
proc Notebook:pageconfig {w name args} {
  global Notebook
  set i [lsearch $Notebook($w,pages) $name]
  if {$i<0} return
  foreach {tag value} $args {
    switch -- $tag {
      -state {
        if {"$value"=="disabled"} {
          $w itemconfig t$i -fill $Notebook($w,fg,off)
	    set Notebook($w,t$i,state) 0
        } else {
          $w itemconfig t$i -fill $Notebook($w,fg,on)
	    set Notebook($w,t$i,state) 1
        }
      }
      -command {
        set Notebook($w,c$i,command) $value
      }
      -onexit {
        set Notebook($w,p$i,onexit) $value
      }
    }
  }
}

#
# This procedure raises a notebook page given its name.  But first
# we check the "onexit" procedure for the current page (if any) and
# if it returns false, we don't allow the raise to proceed.
#
proc Notebook:raise {w name} {

}

#
# Return the frame associated with a given page of the notebook.
#
proc Notebook:frame {w name} {
  global Notebook
    global command
  set i [lsearch $Notebook($w,pages) $name]
  if {$i>=0} {
    return $w.f$i
  } else {
    return {}
  }
}

#
# Try to resize the notebook to the next time we become idle.
#
proc Notebook:scheduleExpand w {

}

#
# Resize the notebook to fit inside its containing widget.
#
proc Notebook:expand w {

}

#
# Resize the notebook so that it fits the contents.
#
proc Notebook:resize w {

}
